@@ -44,19 +44,17 @@ public:
         QStringList list;
         const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("carddecks"), QStandardPaths::LocateDirectory);
         for (const QString& dir : dirs) {
-            const QStringList deckFolderNames = QDir(dir).entryList(QStringList() << QStringLiteral("svg*"));
+            const QStringList deckFolderNames = QDir(dir).entryList({QStringLiteral("svg*")});
+            list.reserve(list.size() + deckFolderNames.size());
             for (const QString& deck : deckFolderNames) {
-                list.append(dir + '/' + deck + QStringLiteral("/index.desktop"));
+                list.append(dir + QLatin1Char('/') + deck + QStringLiteral("/index.desktop"));
             }
         }
 
-        if (list.isEmpty()) return;
-
-        for (QStringList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it)
-        {
-            KConfig cfg(*it, KConfig::SimpleConfig);
-            KConfigGroup cfgcg(&cfg, "KDE Backdeck");
-            QString path = (*it).left((*it).lastIndexOf(QLatin1Char('/')) + 1);
+        for (const QString &deckPath : std::as_const(list)) {
+            KConfig cfg(deckPath, KConfig::SimpleConfig);
+            KConfigGroup cfgcg(&cfg, QStringLiteral("KDE Backdeck"));
+            QString path = deckPath.left(deckPath.lastIndexOf(QLatin1Char('/')) + 1);
             Q_ASSERT(path[path.length() - 1] == QLatin1Char('/'));
             QPixmap pixmap(path + cfgcg.readEntry("Preview", "12c.png"));
             if (pixmap.isNull()) continue;
